# 06 Dubin's Car: Conditional Statements and Signal Temporal Logic

!!! Warning "Work In Progress"
    This tutorial is under development!

## Further Reading

- [API Reference: Logic operators](../Reference/symbolic/expr/logic.md)
- [API Reference: STL operators](../Reference/symbolic/expr/stl.md)
- [Dubin's Car with conditional logic Example](../Examples/car/dubins_car_conditional.md)
- [Dubin's Car with direct STL implementation Example](../Examples/car/dubins_car_disjoint.md)
- [Dubin's Car with STLJAX Example](../Examples/car/dubins_car_stljax.md)